From: Jeroen Dekkers <jeroen@dekkers.ch>
Date: Wed, 9 Apr 2014 22:59:40 +0200
Subject: Fix "may be used uninitialized in this function" warnings.

Forwarded: https://github.com/inverse-inc/sogo/pull/33

Index: sogo-5.6.0/SoObjects/SOGo/SOGoCacheGCSFolder.m
===================================================================
--- sogo-5.6.0.orig/SoObjects/SOGo/SOGoCacheGCSFolder.m
+++ sogo-5.6.0/SoObjects/SOGo/SOGoCacheGCSFolder.m
@@ -208,14 +208,18 @@ Class SOGoCacheGCSObjectK = Nil;
   NSArray *records;
   NSDictionary *record;
   NSUInteger count, max;
+  /* We make this a local variable so gcc knows it can't be changed in the super
+     method. This way we don't get a "may be used uninitialized in this
+     function" warning for oldPath. */
+  BOOL nameInContainerBool = nameInContainer ? YES : NO;
 
   /* change the paths in children records */
-  if (nameInContainer)
+  if (nameInContainerBool)
     oldPath = [self path];
 
   [super setNameInContainer: newName];
 
-  if (nameInContainer)
+  if (nameInContainerBool)
     {
       newPath = [self path];
 
Index: sogo-5.6.0/SoObjects/SOGo/SOGoCacheGCSObject.m
===================================================================
--- sogo-5.6.0.orig/SoObjects/SOGo/SOGoCacheGCSObject.m
+++ sogo-5.6.0/SoObjects/SOGo/SOGoCacheGCSObject.m
@@ -245,13 +245,17 @@ static EOAttribute *textColumn = nil;
 {
   NSMutableString *sql;
   NSString *oldPath, *newPath;
+  /* We make this a local variable so gcc knows it can't be changed in the super
+     method. This way we don't get a "may be used uninitialized in this
+     function" warning for oldPath. */
+  BOOL nameInContainerBool = nameInContainer ? YES : NO;
 
-  if (nameInContainer)
+  if (nameInContainerBool)
     oldPath = [self path];
 
   [super setNameInContainer: newNameInContainer];
 
-  if (nameInContainer)
+  if (nameInContainerBool)
     {
       newPath = [self path];
       
